plottwist
============================================================

Core implementation for ArtellaPipe based Plot Twist Pipeline

.. image:: https://travis-ci.com/Plot-Twist-Short-Film/plottwist-core.svg?branch=master&kill_cache=1
    :target: https://travis-ci.com/Plot-Twist-Short-Film/plottwist-core

.. image:: https://coveralls.io/repos/github/Plot-Twist-Short-Film/plottwist-core/badge.svg?branch=master&kill_cache=1
    :target: https://coveralls.io/github/Plot-Twist-Short-Film/plottwist-core?branch=master

.. image:: https://img.shields.io/badge/docs-sphinx-orange
    :target: https://Plot-Twist-Short-Film.github.io/plottwist-core/

.. image:: https://img.shields.io/github/license/Plot-Twist-Short-Film/plottwist-core
    :target: https://github.com/Plot-Twist-Short-Film/plottwist-core/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/plottwist-core?branch=master&kill_cache=1
    :target: https://pypi.org/project/plottwist-core/

.. image:: https://img.shields.io/badge/code_style-pep8-blue
    :target: https://www.python.org/dev/peps/pep-0008/